/****************************************************************************
 ** This file is part of the MAIA (Malagasy Artificial Intelligence Art) Open Project.
 **
 ** Copyright (C) 2012, 2013 ANDRIAMILAMINA Monge.
 ** All rights reserved.
 **
 ** License: GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007.
 ** Author:  ANDRIAMILAMINA Monge.
 ** Contact: mongemilamina@gmail.com / +261 34 45 062 85.
 ** Year:    2013.
 ** Status:  MAIA Senior Engineer, Madagasikara, Antananarivo.
 ** Domain:  Automatic.
 **
 ** Commercial Usage
 ** Please contact MAIA.
 **
 ** GNU General Public License Usage
 ** This file may be used under the terms of the GNU
 ** General Public License version 3.0 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU General Public License version 3.0 requirements will be
 ** met: http://www.gnu.org/copyleft/gpl.html.
 **
 ** If you have questions regarding the use of this file, please contact
 ** the Author.
 **
 ****************************************************************************/

#ifndef UNITCONV_H
#define UNITCONV_H

#include <QMainWindow>
#include <QAction>
#include <QTabWidget>
#include <QLabel>
#include <QDoubleValidator>
#include <QMenu>

namespace Ui {
class UnitConv;
}

class UnitConv : public QMainWindow {
    Q_OBJECT
public:
    UnitConv(QWidget *parent = 0);
    ~UnitConv();
private slots:
    void aboutAndHelp();
    void new_();

    void footToMeter();
    void meterToFoot();

    void nauticalToKilMeter();
    void kiloMeterToNautical();

    void inchToMilliMeter();
    void milliMeterToInch();

    void celsiusToKelvin();
    void kelvinToCelsius();

    void mileToKiloMeter();
    void kiloMeterToMile();

    void noeudsToMeterPerSec();
    void meterPerSecToNoeuds();

    void handleCopies();
    void copyToConvertLine();
    void copyConvertedLine();

    void closeEvent(QCloseEvent *ev);

protected:
    void changeEvent(QEvent *e);

private:

    QAction* myActionNew;
    QAction* myActionAboutAndHelp;
    QAction* myActionCopyToConvertLine;
    QAction* myActionCopyConvertedLine;
    QAction* myActionQuit;

    QMenu* myMenuOperations;
    QMenu* myMenuCopies;
    QMenu* myMenuAboutAndHelp;

    QTabWidget* myTabWidget;
    QLabel* myAboutLab;
    QLabel* myHelpLab;

    QDoubleValidator* myValidator;

    Ui::UnitConv *ui;

};

#endif // UNITCONV_H
